# For Emacs: -*- mode:cperl; eval: (folding-mode 1); coding:utf-8 -*-

package Lingua::SQI::Num2Word;
# ABSTRACT: Number to word conversion in Albanian

use 5.16.0;
use utf8;
use warnings;

# {{{ use block

use Carp;
use Export::Attrs;
use Readonly;

# }}}
# {{{ variable declarations

my Readonly::Scalar $COPY = 'Copyright (c) PetaMem, s.r.o. 2002-present';
our $VERSION = '0.2603270';

# }}}

# {{{ num2sqi_cardinal                 convert number to text

sub num2sqi_cardinal :Export {
    my $positive = shift;

    croak 'You should specify a number from interval [0, 999_999_999]'
        if    !defined $positive
           || $positive !~ m{\A\d+\z}xms
           || $positive < 0
           || $positive > 999_999_999;

    my @ones = qw(zero një dy tre katër pesë gjashtë shtatë tetë nëntë);
    my @teens = qw(
        dhjetë njëmbëdhjetë dymbëdhjetë trembëdhjetë katërmbëdhjetë
        pesëmbëdhjetë gjashtëmbëdhjetë shtatëmbëdhjetë tetëmbëdhjetë nëntëmbëdhjetë
    );
    my @tens = qw(
        _invalid _invalid njëzet tridhjetë dyzet pesëdhjetë
        gjashtëdhjetë shtatëdhjetë tetëdhjetë nëntëdhjetë
    );

    return $ones[$positive]              if ($positive >= 0 && $positive < 10);
    return $teens[$positive - 10]        if ($positive >= 10 && $positive < 20);

    my $out;
    my $remain;

    if ($positive >= 20 && $positive < 100) {                  # 20 .. 99
        my $ten_idx = int($positive / 10);
        $remain     = $positive % 10;

        $out = $tens[$ten_idx];
        $out .= ' e ' . $ones[$remain] if ($remain);
    }
    elsif ($positive >= 100 && $positive < 1000) {             # 100 .. 999
        my $hund_idx = int($positive / 100);
        $remain      = $positive % 100;

        $out  = $ones[$hund_idx] . 'qind';
        $out .= ' e ' . num2sqi_cardinal($remain) if ($remain);
    }
    elsif ($positive >= 1000 && $positive < 1_000_000) {       # 1000 .. 999_999
        my $kilo_idx = int($positive / 1000);
        $remain      = $positive % 1000;

        $out  = num2sqi_cardinal($kilo_idx) . ' mijë';
        $out .= ' e ' . num2sqi_cardinal($remain) if ($remain);
    }
    elsif ($positive >= 1_000_000 && $positive < 1_000_000_000) { # 1_000_000 .. 999_999_999
        my $mega_idx = int($positive / 1_000_000);
        $remain      = $positive % 1_000_000;

        $out  = num2sqi_cardinal($mega_idx);
        $out .= $mega_idx == 1 ? ' milion' : ' milionë';
        $out .= ' e ' . num2sqi_cardinal($remain) if ($remain);
    }

    return $out;
}

# }}}


# {{{ capabilities              declare supported features

sub capabilities {
    return {
        cardinal => 1,
        ordinal  => 0,
    };
}

# }}}
1;

__END__

# {{{ POD HEAD

=pod

=encoding utf-8

=head1 NAME

Lingua::SQI::Num2Word - Number to word conversion in Albanian


=head1 VERSION

version 0.2603270

Lingua::SQI::Num2Word is a module for converting numbers into their written
representation in Albanian. Converts whole numbers from 0 up to 999 999 999.

Text output is encoded in UTF-8.

=cut

# }}}
# {{{ SYNOPSIS

=pod

=head1 SYNOPSIS

 use Lingua::SQI::Num2Word;

 my $text = Lingua::SQI::Num2Word::num2sqi_cardinal( 123 );

 print $text || "sorry, can't convert this number into Albanian.";

=cut

# }}}
# {{{ Functions Reference

=pod

=head1 Functions Reference

=over 2

=item B<num2sqi_cardinal> (positional)

  1   num    number to convert
  =>  str    converted string
      undef  if input number is not known

Convert number to text representation in Albanian.
Only numbers from interval [0, 999_999_999] will be converted.

=back

=cut

# }}}
# {{{ EXPORTED FUNCTIONS

=pod

=head1 EXPORT_OK

=over 2

=item num2sqi_cardinal

=back

=cut

# }}}
# {{{ POD FOOTER

=pod

=head1 AUTHORS

 specification, maintenance:
   Richard C. Jelinek E<lt>rj@petamem.comE<gt>
 coding (2026-present):
   PetaMem AI Coding Agents

=head1 COPYRIGHT

Copyright (c) PetaMem, s.r.o. 2002-present

=head1 LICENSE

This module is free software; you can redistribute it and/or modify it
under the same terms as the Artistic License 2.0 or the BSD 2-Clause
License. See the LICENSE file in the distribution for details.

=cut

# }}}
